@@ -77,6 +77,10 @@ void        html_table_end_row      (HTMLTable      *table);
 void        html_table_start_row    (HTMLTable      *table);
 void        html_table_add_cell     (HTMLTable      *table,
 				     HTMLTableCell  *cell);
+void        html_table_set_cell     (HTMLTable *table, 
+				     gint r, 
+				     gint c, 
+				     HTMLTableCell *cell);
 void        html_table_remove_cell  (HTMLTable      *table,
 				     HTMLTableCell  *cell);
 gint        html_table_end_table    (HTMLTable      *table);
